@@ -4,6 +4,7 @@ import sys
 import json
 import datetime
 import base64
+import socket
 from tup import *
 
 class UserEndCycleException(Exception):
@@ -17,25 +18,23 @@ class Controller:
   READ_SOFT_TIMEOUT = 20 # Amount of time to wait until we send a 'ping' to the parent
   DEATH_TIMEOUT = READ_SOFT_TIMEOUT * 3  # If no activity from the parent (even response to a ping) time before we kill ourself.
 
-  def __init__(self, named_pipe, emits):
+  def __init__(self, host, port, emits):
     self.last_activity = None
     self.emits = emits
-    if(os.path.exists(named_pipe+".in")):
-      self.pipe_to_java = open(named_pipe+".in","w+")
+    if(host != None and port != None):
+      sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+      sock.connect((host, int(port)))
+      self.socket_to_java = sock.makefile('r+w', 1)
+      self.socket_from_java = self.socket_to_java
     else:
-      self.pipe_to_java = sys.stdout
-
-    if(os.path.exists(named_pipe+".out")):
-      self.pipe_from_java = open(named_pipe+".out","r+")
-    else:
-      self.pipe_from_java = sys.stdin
+      self.socket_to_java = sys.stdout
+      self.socket_from_java = sys.stdin
 
   def pjson(self, m):
     jd = json.dumps(m)
-    self.pipe_to_java.write(jd+"\n")
-    self.pipe_to_java.write("end")
-    self.pipe_to_java.write("\n")
-    self.pipe_to_java.flush()
+    self.socket_to_java.write(jd+"\n")
+    self.socket_to_java.write("end\n")
+    self.socket_to_java.flush()
 
   def emit(self, *args):
     # convert tuple to json, print to stdout
@@ -98,16 +97,16 @@ class Controller:
     raise UserEndCycleException("cycle ended")
 
   def check_end(self):
-    line = self.pipe_from_java.readline()
+    line = self.socket_from_java.readline()
     while line != "end\n":
       self.log("Missing end checking next line")
-      line = self.pipe_from_java.readline()
+      line = self.socket_from_java.readline()
     return True
 
   def read(self):
     def timed_read(c, m):
       try:
-        line = c.pipe_from_java.readline()
+        line = c.socket_from_java.readline()
         try:
           d = json.loads(line)
           m["msg"] = d
